@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2001 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Type registration tool.
-
-$Id: TypesTool.py 106204 2009-12-04 10:10:11Z yuppie $
-"""
+""" Type registration tool. """
 
 import logging
 from warnings import warn
@@ -396,7 +393,7 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
             lazy_keys.append('icon')
         else:
             lazy_map['icon'] = ''
-        lazy_map['link_target'] = self.link_target
+        lazy_map['link_target'] = self.link_target or None
         lazy_map['visible'] = True
         lazy_map['available'] = self._checkAvailable
         lazy_map['allowed'] = self._checkAllowed
@@ -408,8 +405,12 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
         if isinstance(value, list):
             value = tuple(value)
         setattr(self, id, value)
-        if value and id.endswith('_expr'):
-            setattr(self, '%s_object' % id, Expression(value))
+        if id.endswith('_expr'):
+            attr = '%s_object' % id
+            if value:
+                setattr(self, attr, Expression(value))
+            elif hasattr(self, attr):
+                delattr(self, attr)
 
     def _checkAvailable(self, ec):
         """ Check if the action is available in the current context.
