@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Site properties xml adapters and setup handlers.
-
-$Id: properties.py 91451 2008-09-24 19:57:57Z jens $
-"""
+"""Site properties xml adapters and setup handlers. """
 
 from zope.component import adapts
 from zope.component import queryMultiAdapter
