@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Filesystem exporter / importer adapter unit tests.
-
-$Id: test_content.py 119566 2011-01-13 15:38:42Z gotcha $
-"""
+"""Filesystem exporter / importer adapter unit tests. """
 
 import unittest
 import Testing
