@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Types tool xml adapter and setup handler unit tests.
-
-$Id: test_typeinfo.py 110577 2010-04-07 06:33:17Z jens $
-"""
+"""Types tool xml adapter and setup handler unit tests. """
 
 import unittest
 import Testing
