@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for ActionInformation module.
-
-$Id: test_ActionInformation.py 112729 2010-05-26 15:08:55Z jens $
-"""
+""" Unit tests for ActionInformation module. """
 
 import unittest
 import Testing
