@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Unit tests for CMFCatalogAware.
-
-$Id: test_CMFCatalogAware.py 110577 2010-04-07 06:33:17Z jens $
-"""
+"""Unit tests for CMFCatalogAware. """
 
 import unittest
 import Testing
