@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""CookieCrumbler tests.
-
-$Id: test_CookieCrumbler.py 115542 2010-08-08 10:36:11Z hannosch $
-"""
+"""CookieCrumbler tests. """
 
 import unittest
 import Testing
