@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for DynamicType module.
-
-$Id: test_DynamicType.py 110577 2010-04-07 06:33:17Z jens $
-"""
+""" Unit tests for DynamicType module. """
 
 import unittest
 import Testing
