@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for FSDTMLMethod module.
-
-$Id: test_FSDTMLMethod.py 110577 2010-04-07 06:33:17Z jens $
-"""
+""" Unit tests for FSDTMLMethod module. """
 
 import unittest
 import Testing
