@@ -1,7 +1,7 @@
 # -*- coding: iso-8859-1 -*-
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,10 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for FSPageTemplate module.
-
-$Id: test_FSPageTemplate.py 101693 2009-07-07 12:00:01Z yuppie $
-"""
+""" Unit tests for FSPageTemplate module. """
 
 import unittest
 from Testing import ZopeTestCase
