@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for PortalFolder module.
-
-$Id: test_PortalFolder.py 115237 2010-07-30 14:55:08Z jens $
-"""
+""" Unit tests for PortalFolder module. """
 
 import unittest
 import Testing
