@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for TypesTool module.
-
-$Id: test_TypesTool.py 110577 2010-04-07 06:33:17Z jens $
-"""
+""" Unit tests for TypesTool module. """
 
 import unittest
 
