@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for WorkflowTool module.
-
-$Id: test_WorkflowTool.py 96733 2009-02-19 11:35:31Z yuppie $
-"""
+""" Unit tests for WorkflowTool module. """
 
 import unittest
 import Testing
